@@ -87,14 +87,6 @@ COPYRIGHT
     Please see the LICENSE file for more information.
 """
 
-################################################################################
-# Module metadata ##############################################################
-################################################################################
-
-__author__ = "Kristoffer A. Wright"
-__version__ = "1.0.0"
-__license__ = "MIT"
-
 ################################################################################
 # Imports ######################################################################
 ################################################################################
@@ -102,7 +94,7 @@ __license__ = "MIT"
 # Standard library:
 import argparse
 import sys
-from typing import List, Tuple
+from typing import List
 
 # Third party:
 import bottle
